@@ -9,8 +9,9 @@ function(model, class) {
   # EXTRACT MODEL LINK
   link <- if(all(class%in%c("lm")) || all(class%in%c("lme")) ||
     any(class%in%"nlme") || any(class%in%"lmerMod")) "identity" else 
-    if(any(class %in% c("clogit"))) "logit" else if(all(class %in% c("coxph")))
-    "log" else if(any(class %in% c("glm")) || any(class %in% c("glmmPQL")))
+    if(any(class %in% c("clogit"))) "logit" else
+    if(any(class %in% c("coxph","coxme"))) "log" else
+    if(any(class %in% c("glm")) || any(class %in% c("glmmPQL")))
     model$family$link else if(any(class %in% c("glmerMod")))
     model@resp$family$link else NA
 #
